import logging
from argparse import ArgumentParser
from pathlib import Path

import psutil

from pid_file_checker.exceptions import InvalidPidError

logger = logging.getLogger(__name__)


def main():
    parser = ArgumentParser(
        description="Check for the presence of a pid file. "
        "The file must contain one and only one integer "
        "which must be the pid of a running process. "
        "Otherwise, return a code != 0. "
        "Meant to be used in a healthcheck context like with Docker or Kubernetes.",
        epilog="Brought to you by IT4NW@ITSF.",
    )
    parser.add_argument(
        "pid_file",
        help="The pid file you want to monitor",
    )
    args = parser.parse_args()
    pid_file = Path(args.pid_file)
    checker(pid_file)


def checker(pid_file: Path):
    if not pid_file.is_file():
        raise FileNotFoundError("Celery beat is not running yet")

    content = pid_file.read_text()
    try:
        pid = int(content)
    except ValueError:
        raise InvalidPidError("Found pid file but content is not an integer")

    if psutil.pid_exists(pid):
        logger.info("Celery beat is alive at pid %s", pid)
    else:
        raise InvalidPidError(f"Found pid file but content is not a pid: {pid}")


if __name__ == "__main__":
    main()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pid_file_checker']

package_data = \
{'': ['*']}

install_requires = \
['psutil>=5.8.0']

entry_points = \
{'console_scripts': ['pfc = pid_file_checker.checker:main']}

setup_kwargs = {
    'name': 'pid-file-checker',
    'version': '1.0.1',
    'description': 'Monitor a pid file',
    'long_description': '# pid-file-checker\n\n```\n$ pfc --help\nusage: pfc [-h] pid_file\n\nCheck for the presence of a pid file. The file must contain one and only one\ninteger which must be the pid of a running process. Otherwise, return a code\n!= 0. Meant to be used in a healthcheck context like with Docker or\nKubernetes.\n\npositional arguments:\n  pid_file    The pid file you want to monitor\n\noptional arguments:\n  -h, --help  show this help message and exit\n\nBrought to you by IT4NW@ITSF.\n```\n',
    'author': 'Gabriel Augendre',
    'author_email': 'gabriel.augendre@itsfactory.fr',
    'maintainer': 'Gabriel Augendre',
    'maintainer_email': 'gabriel.augendre@itsfactory.fr',
    'url': 'https://github.com/itsolutionsfactory/pid-file-checker',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7',
}


setup(**setup_kwargs)
